package com.atguigu.ssyx.sys.service.impl;

import com.atguigu.ssyx.common.exception.BunnyException;
import com.atguigu.ssyx.common.result.ResultCodeEnum;
import com.atguigu.ssyx.model.sys.RegionWare;
import com.atguigu.ssyx.sys.mapper.RegionWareMapper;
import com.atguigu.ssyx.sys.service.RegionWareService;
import com.atguigu.ssyx.vo.sys.RegionWareQueryVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

@Service
public class RegionWareServiceImpl extends ServiceImpl<RegionWareMapper, RegionWare> implements RegionWareService {

    /**
     * 开通区域列表
     */
    @Override
    public IPage<RegionWare> selectPage(Page<RegionWare> pageParam, RegionWareQueryVo regionWareQueryVo) {
        String keyword = regionWareQueryVo.getKeyword();
        LambdaQueryWrapper<RegionWare> wrapper = new LambdaQueryWrapper<>();

        // 查询
        wrapper.like(!StringUtils.isEmpty(keyword), RegionWare::getRegionName, keyword).or().like(!StringUtils.isEmpty(keyword), RegionWare::getWareName, keyword);

        return baseMapper.selectPage(pageParam, wrapper);
    }

    /**
     * 添加开通区域
     */
    @Override
    public void saveRegionWare(RegionWare regionWare) {
        // 查询当前区域是否开通
        Integer count = baseMapper.selectCount(Wrappers.<RegionWare>lambdaQuery().eq(RegionWare::getRegionId, regionWare.getRegionId()));
        if (count > 0) {
            throw new BunnyException(ResultCodeEnum.REGION_OPEN);
        }

        baseMapper.insert(regionWare);
    }

    /**
     * 取消开通区域
     */
    @Override
    public void updateStatus(Long id, Integer status) {
        RegionWare regionWare = baseMapper.selectById(id);
        regionWare.setStatus(status);
        // 更新数据
        baseMapper.updateById(regionWare);
    }
}
